@@ -28,7 +28,7 @@ function(X,
          tol = 1e-06,
          keepX = c(rep(ncol(X), ncomp)), 
          keepY = c(rep(ncol(Y), ncomp)),
-         scaleY = TRUE)
+         ...)
 {
 
     #-- validation des arguments --#
@@ -42,7 +42,6 @@ function(X,
         stop("'X' and/or 'Y' must be a numeric matrix.")
      
     n = nrow(X)
-    p = ncol(X)
     q = ncol(Y)
      
     if ((n != nrow(Y))) 
@@ -51,6 +50,15 @@ function(X,
     if (is.null(ncomp) || !is.numeric(ncomp) || ncomp <= 0)
         stop("invalid number of variates, 'ncomp'.")
      
+    nzv = nearZeroVar(X, ...)
+    if (length(nzv$Position > 0)) {
+        warning("Zero- or near-zero variance predictors. 
+  Reset predictors matrix to not near-zero variance predictors.
+  See $nzv for problematic predictors.")
+        X = X[, -nzv$Position]
+    }
+	p = ncol(X)
+	
     ncomp = round(ncomp)
     if(ncomp > p) {
         warning("Reset maximum number of variates 'ncomp' to ncol(X) = ", p, ".")
@@ -94,7 +102,7 @@ function(X,
      
     #-- centrer et rduire les donnes --#
     X = scale(X, center = TRUE, scale = TRUE)
-    if(scaleY == TRUE) Y = scale(Y, center = TRUE, scale = TRUE) 
+    Y = scale(Y, center = TRUE, scale = TRUE) 
 
 
     X.temp = X
@@ -302,7 +310,8 @@ function(X,
                   variates = list(X = mat.t, Y = mat.u),
                   loadings = list(X = mat.a, Y = mat.b),
                   names = list(X = X.names, Y = Y.names, indiv = ind.names))
-     
+    if (length(nzv$Position > 0)) result$nzv = nzv
+	
     class(result) = c("spls", "pls") 
     return(invisible(result))
 }
